#!/bin/sh

# Build Script written for 'fakenes'
# Project home page: http://fakenes.sourceforge.net/
# Source URL: http://fakenes.sourceforge.net/fakenes-0.5.9-beta3.tar.gz
# Build Dependencies: zenwalk-4.6,imagemagick,allegro,requiredbuilder-0.16+
# Created By: raphael
# Maintainer E-Mail: rts417@yahoo.com
# Date of Build-Script Completion: Monday, August 6, 2007



# Package Variables.

name='fakenes'
version='0.5.9'
build='48.1'



# Architecture Variables.

arch='i486'
tune='i686'



# Local Variables.

buildDir=$(pwd)
srcPkg=$buildDir/$name-$version-beta3.tar.gz
srcDir=$buildDir/$name-$version-beta3
package=$name-$version-$arch-$build
dest=$buildDir/$package



# Clean The Work Area, Prepare New Build Area

cd $buildDir
rm -rf $dest
rm -rf $package.tgz
rm -rf $package.md5
rm -rf $package.dep
rm -rf $srcDir
tar -xvf $srcPkg
mkdir -p $dest
mkdir -p $dest/usr/doc/$name-$version
mkdir -p $dest/usr/src/$name-$version
mkdir -p $dest/install
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/bin/



# Set Ownership, Permissions, And C Flags.

chown -R root:root .
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;



# Modify the Makefile

sed "s:CFLAGS=-O2 -W -Wall:CFLAGS=-O2 -march=$arch -mtune=$tune:g" <$srcDir/Makefile >$srcDir/Makefile.new
rm -r $srcDir/Makefile
mv $srcDir/Makefile.new $srcDir/Makefile



# Make And Install The Binary

cd $srcDir
make DESTDIR=$dest
cp fakenes $dest/usr/bin/fakenes
cd $buildDir



# Strip Executables (Comment Out This Section For Debugging Information).

cd $dest
chown -R root:root $dest/usr/bin
( cd $dest
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)



# Copy Documentation.

cp -R $srcDir/docs/* $dest/usr/doc/$name-$version



# Copy The Build Script To The Package.

cp $buildDir/build-$name.sh $dest/usr/src/$name-$version/build-$name.sh



# Create The Slack Description File.

#    |-----handy-ruler------------------------------------------------------|
cat <<EOF > $dest/install/slack-desc
$name: A Nintendo Entertainment System emulator.
$name:
$name: Fakenes is an open-source, portable Nintendo Entertainment System
$name: emulator written in C, using the Allegro game library.
$name:
$name:
$name:
$name:
$name:
$name:
$name:
EOF



# Convert The Icon To The Correct Size and Location

convert $srcDir/support/fakenes.ico -adaptive-resize 48x48 -sharpen 48x48 $dest/usr/share/icons/hicolor/48x48/apps/fakenes.png
mv $dest/usr/share/icons/hicolor/48x48/apps/fakenes-1.png $dest/usr/share/icons/hicolor/48x48/apps/fakenes.png
rm -f $dest/usr/share/icons/hicolor/48x48/apps/fakenes-?.png


# Create Desktop Menu Entry

cat <<EOF > $dest/usr/share/applications/$name.desktop
[Desktop Entry]
Encoding=UTF-8
Name=FakeNES
Comment=Nintendo Emulator
Exec=fakenes
Terminal=false
Type=Application
Categories=Game;Emulator
Icon=fakenes
EOF



# Create The Package And Clean Up

cd $dest
makepkg -l y -c n $buildDir/$package.tgz
cd $buildDir

rm -rf $srcDir
rm -rf $dest



# Create The .dep File

requiredbuilder -r -z $package.tgz > $package.dep



# Generate The MD5 Checksum

md5sum $package.tgz > $package.md5